<?php

declare(strict_types=1);

namespace Drupal\mapsemble\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Site\Settings;
use Drupal\mapsemble\MapsembleApi;

/**
 * Configure Mapsemble settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'mapsemble_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['mapsemble.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(
    array $form,
    FormStateInterface $form_state,
  ): array {
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $this->config('mapsemble.settings')->get('api_key'),
      '#description' => $this->t(
          'Get your API key on <a href="@link" target="_blank">Mapsemble</a>. Add your API Key here or to your settings.(local.).php file (preferred method) as as follows: <br><br> <code>$config[\'mapsemble.settings\'][\'api_key\'] = \'your-key\'</code>',
          [
            '@link' => (Settings::get('mapsemble_app_base') ?? MapsembleApi::MAPSEMBLE_APP_BASE) . '/drupal',
          ]
      ),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(
    array &$form,
    FormStateInterface $form_state,
  ): void {
    $this->config('mapsemble.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
